package com.xinelu.manage.mapper.goodsInfo;

import com.xinelu.manage.domain.goodsInfo.GoodsInfo;
import com.xinelu.manage.domain.nursestation.NurseStation;
import com.xinelu.manage.domain.storeInfo.StoreInfo;
import com.xinelu.manage.dto.goodsInfo.GoodsAttributeDTO;
import com.xinelu.manage.vo.goodsInfo.GetGoodDetails;
import com.xinelu.manage.vo.goodsInfo.GoodsInfoVO;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 商品基本信息Mapper接口
 *
 * @author xinyilu
 * @date 2022-10-17
 */
public interface GoodsInfoMapper {
    /**
     * 查询商品基本信息
     *
     * @param id 商品基本信息主键
     * @return 商品基本信息
     */
    GoodsInfo selectGoodsInfoById(Long id);

    /**
     * 查询商品基本信息列表
     *
     * @param goodsInfo 商品基本信息
     * @return 商品基本信息集合
     */
    List<GoodsInfo> selectGoodsInfoList(GoodsInfo goodsInfo);

    /**
     * 新增商品基本信息
     *
     * @param goodsInfo 商品基本信息
     * @return 结果
     */
    int insertGoodsInfo(GoodsInfo goodsInfo);

    /**
     * 修改商品基本信息
     *
     * @param goodsInfo 商品基本信息
     * @return 结果
     */
    int updateGoodsInfo(GoodsInfo goodsInfo);

    /**
     * 删除商品基本信息
     *
     * @param id 商品基本信息主键
     * @return 结果
     */
    int deleteGoodsInfoById(Long id);

    /**
     * 批量删除商品基本信息
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteGoodsInfoByIds(Long[] ids);

    /**
     * 查询商品基本信息
     *
     * @param goodsInfoVO 商品基本信息
     * @return java.util.List<com.xinyilu.base.vo.goodsInfo.GoodsInfoVO>
     **/
    List<GoodsInfoVO> getGoodsInfoList(GoodsInfoVO goodsInfoVO);

    /**
     * 商品属性信息
     *
     * @param goodsInfoId 商品详细id
     * @return java.util.List<com.xinyilu.nurseapplet.domain.nursingStationGoods.GoodDetailsList>
     **/
    GetGoodDetails getGoodsDetailsList(Long goodsInfoId);

    /**
     * 修改商品上架状态基本信息
     *
     * @param goodsInfo 商品基本信息
     * @return 结果
     */
    int updateGoodsWhetherShelf(GoodsInfo goodsInfo);

    /**
     * 查询店铺信息
     *
     * @param nurseStationId 店铺信息主键
     * @return 店铺信息
     */
    StoreInfo getStoreInfoById(Long nurseStationId);

    /**
     * 新增店铺信息
     *
     * @param storeInfo 店铺信息
     * @return 结果
     */
    int insertStoreInfo(StoreInfo storeInfo);

    /**
     * 查询护理站信息
     *
     * @param id 护理站信息主键
     * @return 护理站信息
     */
    NurseStation getNurseStationById(Long id);

    /**
     * 查询商品基本信息id
     *
     * @param id 商品基本信息id
     * @return java.util.List<com.xinyilu.base.vo.goodsInfo.GoodsInfoVO>
     **/
    List<GoodsAttributeDTO> getGoodsByIdList(Long id);

    /**
     * 查询商品基本信息id
     *
     * @param goodsInfoIdList 商品基本信息id
     * @return java.util.List<com.xinyilu.base.vo.goodsInfo.GoodsInfoVO>
     **/
    List<GoodsAttributeDTO> getGoodsByIdLists(@Param("goodsInfoIdList") List<Long> goodsInfoIdList);

    /**
     * 查询店铺信息
     *
     * @param storeName 店铺名称
     * @return 店铺信息
     */
    StoreInfo getStoreInfoByName(@Param("storeName") String storeName);
}
